import requests
import pandas as pd
from smack_gsheets import Google_Sheet as gs



def Get_Subreddit(self):
        
    sh=gs.Open_Gsheets("Subreddit_Links")
    wrks=gs.Open_Worksheet(sh,'MatchThreads')
    df=gs.Read_Gsheet(wrks)
    urls=df['URLS'].values
    urls_cleaned = [item for item in urls if not (pd.isnull(item)) == True]
    print(urls_cleaned[0])
    for i in urls_cleaned:
        
        score=[]
        comment=[]
        Link=[]
        subreddit=[]
        
        r=requests.get(i,headers={'User-agent': 'Chrome'})
        body=r.json()
        content1=body[0]
        content2=body[1]

        dt=content1['data']
        children_list1=dt['children']
        t3=children_list1[0]
        t3_data=t3['data']
        selftext=t3_data['selftext']
        title=selftext.split("\n")
        title=title[0]

        data=content2['data']
        children_list=data['children']
        print(children_list[1].keys())

        for j in children_list:
            thread_data=j
            match_data=thread_data['data']
            print(match_data.keys())

            try:
                comment.append(match_data['body'])
                score.append(match_data['score'])
                Link.append(match_data['permalink'])
                subreddit.append(match_data['subreddit'])
            except:
                comment.append("NA")
                score.append('NA')
                Link.append('NA')
                subreddit.append('NA')
                
        results={"Subreddit":subreddit,"Comment":comment,"Score":score,"URL":Link}
        df=pd.DataFrame(results)
        df['Match_Thread']=title
        sheet=gs.Open_Gsheets("Reddit_Match_Thread_Data")
        fname=subreddit[0]+"_"+title
        rows=len(df['Comment'].values)
        try:
            newsheet=gs.Create_Gsheet(df,fname,rows,sheet)
            gs.Update_Gsheet(newsheet,df)
        except:
            worksheet=gs.Open_Worksheet(sheet,fname)
            gs.Update_Gsheet(worksheet,df)

    



#!/usr/bin/env python
# coding: utf-8

# In[177]:


import twint

import gspread
from gspread_dataframe import get_as_dataframe, set_with_dataframe

import requests

import pandas as pd


import nest_asyncio


# In[169]:



def Get_Tweets(self,username,no_tweets):
    
    tweets_df=pd.DataFrame()
    try:
        c = twint.Config()
        c.Username = username
        c.Limit = no_tweets
        c.Store_csv = True
        c.Pandas=True
        twint.run.Search(c)
        tweets_df = twint.storage.panda.Tweets_df
    except:
        nest_asyncio.apply()
        self.Get_Tweets(username,no_tweets)
    
    filename="Twitter_Data_"+username
    return(tweets_df,filename)


# In[141]:


def Open_Gsheets(self,name):
    gc = gspread.service_account(filename='mycredentials.json')
    sheet=gc.open(name)
    return(sheet)


# In[135]:


def Open_Worksheet(self,sheets,worksheet_name):
    wrksheet=sheets.worksheet(worksheet_name)
    return wrksheet


# In[96]:


def Create_Gsheet(self,df,fname,rows,sheet):
    cols=len(df.columns)
    newsheet = sheet.add_worksheet(title=fname, rows=rows, cols=cols)
    return(newsheet)


# In[97]:


def Update_Gsheet(self,newsheet,df):
    set_with_dataframe(newsheet, df)
    


# In[157]:


def Read_Gsheet(self,sheets):
    df=get_as_dataframe(sheets)
    return(df)


# In[170]:


def Search(self,filename,Sheets):
    worksheet_list = Sheets.worksheets()
    worksheet_name=[]
    for i in worksheet_list:
        worksheet_obj=str(i)
        splitter=worksheet_obj.split(" ")
        worksheet_filename=splitter[1]
        worksheet=worksheet_filename.split(".")
        worksheet_name.append(worksheet_name[0])
    
    if filename in worksheet:
        return True
    else:
        return False


# In[176]:
def get_data():
    sheets=Open_Gsheets("Journalists")
    wks=sheets.worksheet("Journalists")
    df=Read_Gsheet(wks)
    usernames=df["Usernames"].values.tolist()
    Sheet=Open_Gsheets("Athletic_Tweets")
    for i in usernames:
        tweets_df,fname=Get_Tweets(i,10)
        try:
            newsheet=Create_Gsheet(tweets_df,fname,10,Sheet)
            Update_Gsheet(newsheet,tweets_df)
        except:
            worksheet=Open_Worksheet(Sheet,fname)
            Update_Gsheet(worksheet,tweets_df)








import requests
import pandas as pd
from smack_gsheets import Google_Sheet as gs
#from reddit.json_trial.Google_Sheet import Open_Gsheets



def get_subreddit_data(self):
    
    sh=gs.Open_Gsheets("Subreddit_Links")
    wrks=gs.Open_Worksheet(sh,'Urls')
    df=gs.Read_Gsheet(wrks)
    urls=df['URLs'].values
    pages=df['No:Pages']
    urls_cleaned = [item for item in urls if not (pd.isnull(item)) == True]
    pages_cleaned=[item for item in pages if not(pd.isnull(item)) == True]
    
    for i in urls_cleaned:
        tag=[]
        name=[]
        title=[]
        down_vote=[]
        up_vote=[]
        subreddit_link=[]
        comments=[]
        videos=[]
        media_url=[]
        count=0
        df=pd.DataFrame()
        next_page=''
        after=""

        for k in pages_cleaned:
            url=i+after
            r = requests.get(url, headers={'User-agent': 'Chrome'})
            body = r.json()
            data=body['data']
            next_page=data['after']
            rows=data['dist']
            after=""
            after="?after="+next_page
            children=data['children']
            
            for j in children:
                print(url)
                children_data=j['data']
                name.append(children_data['subreddit'])
                try:
                    tag_dictionary=children_data['link_flair_richtext'][-1]
                    tag.append(tag_dictionary['t'])
                except:
                    tag.append("")
                title.append(children_data['title'])
                up_vote.append(children_data['ups'])
                down_vote.append(children_data['downs'])
                subreddit_link.append(children_data['permalink'])
                comments.append(children_data['num_comments'])
                is_video=children_data['is_video']
                if(is_video):
                    reddit_video=children_data['secure_media']
                    video_data=reddit_video['reddit_video']
                    video_url=video_data['fallback_url']
                    videos.append(video_url)
                    print(video_url)
                else:
                    videos.append(is_video)
                
                try:
                    media_url.append(children_data['url'])
                except:
                    media_url.append("NA")
            
            consolidated_data={'Name':name,'Tags':tag,'Title':title,'Up_Votes':up_vote,'Down_Votes':down_vote,'url':subreddit_link,
                                "Media_URL":media_url,"Videos":videos,"comments":comments}
            
            df=pd.DataFrame(consolidated_data)

            sheet=gs.Open_Gsheets("Reddit_Data")
            fname=name[0]+"_"+"Data"
            
            try:
                newsheet=gs.Create_Gsheet(df,fname,rows*k,sheet)
                gs.Update_Gsheet(newsheet,df)
            except:
                worksheet=gs.Open_Worksheet(sheet,fname)
                gs.Update_Gsheet(worksheet,df)
            "?after="+next_page
